@@ -1,19 +1,6 @@
-/* Copyright (C) 2014 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2014 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "RemoteInterface.h"
@@ -30,28 +17,30 @@
 #include <QCoreApplication>
 #include <QDataStream>
 #include <QHostInfo>
-#include <qimage.h>
 #include <QLabel>
 #include <QNetworkInterface>
 #include <QTcpSocket>
+#include <qimage.h>
 
 #include <memory>
 
 using namespace RemoteControl;
 
 RemoteInterface::RemoteInterface()
-    : m_categories(new CategoryModel(this)), m_categoryItems(new ThumbnailModel(this)), m_thumbnailModel(new ThumbnailModel(this)),
-      m_discoveryModel(new DiscoveryModel(this))
+    : m_categories(new CategoryModel(this))
+    , m_categoryItems(new ThumbnailModel(this))
+    , m_thumbnailModel(new ThumbnailModel(this))
+    , m_discoveryModel(new DiscoveryModel(this))
 {
     m_connection = new Client;
     connect(m_connection, SIGNAL(gotCommand(RemoteCommand)), this, SLOT(handleCommand(RemoteCommand)));
-    connect(m_connection, &Client::gotConnected,this, &RemoteInterface::connectionChanged);
+    connect(m_connection, &Client::gotConnected, this, &RemoteInterface::connectionChanged);
     connect(m_connection, &Client::gotConnected, this, &RemoteInterface::requestInitialData);
     connect(m_connection, &Client::disconnected, this, &RemoteInterface::gotDisconnected);
     connect(m_connection, &Client::disconnected, this, &RemoteInterface::connectionChanged);
-    qRegisterMetaType<RemoteControl::CategoryModel*>("RemoteControl::CategoryModel*");
-    qRegisterMetaType<RemoteControl::ThumbnailModel*>("ThumbnailModel*");
-    qRegisterMetaType<RemoteControl::DiscoveryModel*>("DiscoveryModel*");
+    qRegisterMetaType<RemoteControl::CategoryModel *>("RemoteControl::CategoryModel*");
+    qRegisterMetaType<RemoteControl::ThumbnailModel *>("ThumbnailModel*");
+    qRegisterMetaType<RemoteControl::DiscoveryModel *>("DiscoveryModel*");
 
     QTimer::singleShot(1000, this, SLOT(pushAwayFromStartupState()));
 }
@@ -64,7 +53,7 @@ void RemoteInterface::setCurrentPage(Page page)
     }
 }
 
-void RemoteInterface::setListCategoryValues(const QStringList& values)
+void RemoteInterface::setListCategoryValues(const QStringList &values)
 {
     if (m_listCategoryValues != values) {
         m_listCategoryValues = values;
@@ -82,7 +71,7 @@ void RemoteInterface::gotDisconnected()
     setCurrentPage(Page::UnconnectedPage);
 }
 
-void RemoteInterface::setHomePageImages(const StaticImageResult& command)
+void RemoteInterface::setHomePageImages(const StaticImageResult &command)
 {
     m_homeImage = command.homeIcon;
     emit homeImageChanged();
@@ -94,7 +83,7 @@ void RemoteInterface::setHomePageImages(const StaticImageResult& command)
     emit discoveryImageChanged();
 }
 
-RemoteInterface& RemoteInterface::instance()
+RemoteInterface &RemoteInterface::instance()
 {
     static RemoteInterface interface;
     return interface;
@@ -105,7 +94,7 @@ bool RemoteInterface::isConnected() const
     return m_connection->isConnected();
 }
 
-void RemoteInterface::sendCommand(const RemoteCommand& command)
+void RemoteInterface::sendCommand(const RemoteCommand &command)
 {
     m_connection->sendCommand(command);
 }
@@ -122,7 +111,7 @@ QImage RemoteInterface::discoveryImage() const
 
 void RemoteInterface::setActiveThumbnailModel(RemoteInterface::ModelType type)
 {
-    ThumbnailModel* newModel = (type == ModelType::Thumbnail ? m_thumbnailModel : m_discoveryModel);
+    ThumbnailModel *newModel = (type == ModelType::Thumbnail ? m_thumbnailModel : m_discoveryModel);
     if (newModel != m_activeThumbnailModel) {
         m_activeThumbnailModel = newModel;
         activeThumbnailModelChanged();
@@ -137,7 +126,7 @@ void RemoteInterface::goHome()
 
 void RemoteInterface::goBack()
 {
-    if(m_history.canGoBack())
+    if (m_history.canGoBack())
         m_history.goBackward();
     else
         qApp->quit();
@@ -149,13 +138,13 @@ void RemoteInterface::goForward()
         m_history.goForward();
 }
 
-void RemoteInterface::selectCategory(const QString& category, int type)
+void RemoteInterface::selectCategory(const QString &category, int type)
 {
     m_search.addCategory(category);
     m_history.push(std::unique_ptr<Action>(new ShowCategoryValueAction(m_search, static_cast<CategoryViewType>(type))));
 }
 
-void RemoteInterface::selectCategoryValue(const QString& value)
+void RemoteInterface::selectCategoryValue(const QString &value)
 {
     m_search.addValue(value);
     m_history.push(std::unique_ptr<Action>(new ShowThumbnailsAction(m_search)));
@@ -176,7 +165,7 @@ void RemoteInterface::requestDetails(int imageId)
     m_connection->sendCommand(ImageDetailsRequest(imageId));
 }
 
-void RemoteInterface::activateSearch(const QString& search)
+void RemoteInterface::activateSearch(const QString &search)
 {
     QStringList list = search.split(";;;");
     QString category = list[0];
@@ -228,7 +217,7 @@ void RemoteInterface::setCurrentView(int imageId)
 QString RemoteInterface::networkAddress() const
 {
     QStringList result;
-    for (const QHostAddress& address : QNetworkInterface::allAddresses()) {
+    for (const QHostAddress &address : QNetworkInterface::allAddresses()) {
         if (address.isLoopback() || address.toIPv4Address() == 0)
             continue;
         result.append(address.toString());
@@ -248,45 +237,43 @@ void RemoteInterface::requestInitialData()
     m_history.push(std::unique_ptr<Action>(new ShowOverviewAction({})));
 }
 
-void RemoteInterface::handleCommand(const RemoteCommand& command)
+void RemoteInterface::handleCommand(const RemoteCommand &command)
 {
     if (command.commandType() == CommandType::ThumbnailResult)
-        updateImage(static_cast<const ThumbnailResult&>(command));
+        updateImage(static_cast<const ThumbnailResult &>(command));
     else if (command.commandType() == CommandType::CategoryListResult)
-        updateCategoryList(static_cast<const CategoryListResult&>(command));
+        updateCategoryList(static_cast<const CategoryListResult &>(command));
     else if (command.commandType() == CommandType::SearchResult)
-        gotSearchResult(static_cast<const SearchResult&>(command));
+        gotSearchResult(static_cast<const SearchResult &>(command));
     else if (command.commandType() == CommandType::TimeCommand)
         ; // Used for debugging, it will print time stamp when decoded
     else if (command.commandType() == CommandType::ImageDetailsResult) {
-        ImageDetails::instance().setData(static_cast<const ImageDetailsResult&>(command));
+        ImageDetails::instance().setData(static_cast<const ImageDetailsResult &>(command));
         emit tokensChanged();
-    }
-    else if (command.commandType() == CommandType::CategoryItemsResult)
-        setListCategoryValues(static_cast<const CategoryItemsResult&>(command).items);
+    } else if (command.commandType() == CommandType::CategoryItemsResult)
+        setListCategoryValues(static_cast<const CategoryItemsResult &>(command).items);
     else if (command.commandType() == CommandType::StaticImageResult)
-        setHomePageImages(static_cast<const StaticImageResult&>(command));
+        setHomePageImages(static_cast<const StaticImageResult &>(command));
     else
         qFatal("Unhandled command");
 }
 
-void RemoteInterface::updateImage(const ThumbnailResult& command)
+void RemoteInterface::updateImage(const ThumbnailResult &command)
 {
     ImageStore::instance().updateImage(command.imageId, command.image, command.label, command.type);
 }
 
-void RemoteInterface::updateCategoryList(const CategoryListResult& command)
+void RemoteInterface::updateCategoryList(const CategoryListResult &command)
 {
     ScreenInfo::instance().setCategoryCount(command.categories.count());
     m_categories->setCategories(command.categories);
 }
 
-void RemoteInterface::gotSearchResult(const SearchResult& result)
+void RemoteInterface::gotSearchResult(const SearchResult &result)
 {
     if (result.type == SearchType::Images) {
         m_activeThumbnailModel->setImages(result.result);
-    }
-    else if (result.type == SearchType::CategoryItems) {
+    } else if (result.type == SearchType::CategoryItems) {
         m_categoryItems->setImages(result.result);
     }
 }
