@@ -1,34 +1,21 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ANNOTATIONDIALOG_DIALOG_H
 #define ANNOTATIONDIALOG_DIALOG_H
 
-#include "config-kpa-marble.h"
+#include <kpabase/config-kpa-marble.h>
 
 #include "ImagePreviewWidget.h"
 #include "ListSelect.h"
-#include "enums.h"
 
 #include <DB/Category.h>
 #include <DB/ImageInfoList.h>
 #include <DB/ImageSearchInfo.h>
-#include <Utilities/StringSet.h>
+#include <kpabase/StringSet.h>
+#include <kpabase/enums.h>
 
 #include <QCheckBox>
 #include <QDialog>
