@@ -1,20 +1,6 @@
-/* Copyright 2012-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2012-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "HandleVideoThumbnailRequestJob.h"
@@ -22,13 +8,12 @@
 #include <ImageManager/ExtractOneVideoFrame.h>
 #include <ImageManager/ImageClientInterface.h>
 #include <ImageManager/ImageRequest.h>
-#include <ImageManager/ThumbnailCache.h>
 #include <MainWindow/FeatureDialog.h>
-#include <Settings/SettingsData.h>
 #include <ThumbnailView/CellGeometry.h>
 #include <Utilities/ImageUtil.h>
+#include <kpabase/SettingsData.h>
+#include <kpathumbnails/ThumbnailCache.h>
 
-#include <KCodecs>
 #include <KLocalizedString>
 #include <QCryptographicHash>
 #include <QDir>
