@@ -1,20 +1,7 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2020 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "GeoPositionPage.h"
 
@@ -67,12 +54,15 @@ void Browser::GeoPositionPage::slotNewRegionSelected(Map::GeoCoordinates::LatLon
     DB::ImageSearchInfo info = searchInfo();
 
     info.setRegionSelection(coordinates);
-
-    browser()->addAction(new Browser::OverviewPage(Breadcrumb(name), info, browser()));
     const int numSelected = DB::ImageDB::instance()->search(info).size();
-    qCDebug(BrowserLog) << "Selected region" << coordinates << "with" << numSelected << "images.";
-    if (numSelected <= Settings::SettingsData::instance()->autoShowThumbnailView()) {
-        browser()->addAction(new ImageViewPage(info, browser()));
+    if (numSelected > 0) {
+        browser()->addAction(new Browser::OverviewPage(Breadcrumb(name), info, browser()));
+        qCDebug(BrowserLog) << "Selected region" << coordinates << "with" << numSelected << "images.";
+        if (numSelected <= Settings::SettingsData::instance()->autoShowThumbnailView()) {
+            browser()->addAction(new ImageViewPage(info, browser()));
+        }
+    } else {
+        qCDebug(BrowserLog) << "Ignoring region selection" << coordinates << "without images.";
     }
 }
 
