@@ -1,20 +1,7 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "OverviewPage.h"
 
@@ -30,9 +17,9 @@
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
 #include <Exif/SearchDialog.h>
-#include <MainWindow/Logging.h>
 #include <MainWindow/Window.h>
 #include <Utilities/ShowBusyCursor.h>
+#include <kpabase/Logging.h>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -243,7 +230,7 @@ bool Browser::OverviewPage::isSearchable() const
 
 Browser::BrowserPage *Browser::OverviewPage::activateExivAction()
 {
-    QPointer<Exif::SearchDialog> dialog = new Exif::SearchDialog(browser());
+    QPointer<Exif::SearchDialog> dialog = new Exif::SearchDialog(DB::ImageDB::instance()->exifDB(), browser());
 
     {
         Utilities::ShowBusyCursor undoTheBusyWhileShowingTheDialog(Qt::ArrowCursor);
@@ -257,10 +244,7 @@ Browser::BrowserPage *Browser::OverviewPage::activateExivAction()
             return nullptr;
     }
 
-    Exif::SearchInfo result = dialog->info();
-
     DB::ImageSearchInfo info = BrowserPage::searchInfo();
-
     info.addExifSearchInfo(dialog->info());
 
     delete dialog;
