@@ -1,30 +1,18 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "Category.h"
 
 #include "CategoryItem.h"
 #include "ImageDB.h"
 #include "MemberMap.h"
-#include "UIDelegate.h"
 
-#include <Settings/SettingsData.h>
 #include <Utilities/ImageUtil.h>
+#include <kpabase/Logging.h>
+#include <kpabase/SettingsData.h>
+#include <kpabase/UIDelegate.h>
 
 #include <KLocalizedString>
 #include <QDir>
@@ -171,7 +159,8 @@ void DB::Category::setCategoryImage(const QString &category, QString member, con
         bool ok = QDir().mkdir(dir);
         if (!ok) {
             DB::ImageDB::instance()->uiDelegate().error(
-                QString::fromLatin1("Unable to create CategoryImages directory!"), i18n("Unable to create directory '%1'.", dir), i18n("Unable to Create Directory"));
+                DB::LogMessage { DBLog(), QString::fromLatin1("Unable to create CategoryImages directory!") },
+                i18n("Unable to create directory '%1'.", dir), i18n("Unable to Create Directory"));
             return;
         }
     }
@@ -179,7 +168,8 @@ void DB::Category::setCategoryImage(const QString &category, QString member, con
     ok = image.save(fileName, "JPEG");
     if (!ok) {
         DB::ImageDB::instance()->uiDelegate().error(
-            QString::fromLatin1("Unable to save category image '%1'!").arg(fileName), i18n("Error when saving image '%1'.", fileName), i18n("Error Saving Image"));
+            DB::LogMessage { DBLog(), QString::fromLatin1("Unable to save category image '%1'!").arg(fileName) },
+            i18n("Error when saving image '%1'.", fileName), i18n("Error Saving Image"));
         return;
     }
 
