@@ -1,27 +1,15 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #include "FileInfo.h"
 
-#include <Exif/Info.h>
-#include <Settings/SettingsData.h>
 #include <Utilities/VideoUtil.h>
+#include <kpabase/SettingsData.h>
+#include <kpaexif/Info.h>
 
-#include <QDateTime>
+#include <Utilities/FastDateTime.h>
 #include <QFileInfo>
 #include <QRegularExpression>
 
@@ -105,17 +93,17 @@ void DB::FileInfo::parseEXIV2(const DB::FileName &fileName)
     }
 }
 
-QDateTime FileInfo::fetchEXIV2Date(Exiv2::ExifData &map, const char *key)
+Utilities::FastDateTime FileInfo::fetchEXIV2Date(Exiv2::ExifData &map, const char *key)
 {
     try {
         if (map.findKey(Exiv2::ExifKey(key)) != map.end()) {
             const Exiv2::Exifdatum &datum = map[key];
-            return QDateTime::fromString(QString::fromLatin1(datum.toString().c_str()), Qt::ISODate);
+            return Utilities::FastDateTime::fromString(QString::fromLatin1(datum.toString().c_str()), Qt::ISODate);
         }
     } catch (...) {
     }
 
-    return QDateTime();
+    return Utilities::FastDateTime();
 }
 
 int DB::FileInfo::orientationToAngle(int orientation)
