@@ -1,25 +1,13 @@
-/* Copyright (C) 2018 Robert Krawitz <rlk@alum.mit.edu>
+/* SPDX-FileCopyrightText: 2018 Robert Krawitz <rlk@alum.mit.edu>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "OptimizedFileList.h"
 
 #include "FastDir.h"
-#include "Logging.h"
+
+#include <kpabase/Logging.h>
 
 extern "C" {
 #include <dirent.h>
