@@ -1,30 +1,17 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "InfoDialog.h"
 
 #include "Grid.h"
-#include "Info.h"
+#include <kpaexif/Info.h>
 
 #include <DB/ImageDB.h>
 #include <ImageManager/AsyncLoader.h>
 #include <ImageManager/ImageRequest.h>
-#include <Settings/SettingsData.h>
+#include <kpabase/SettingsData.h>
 
 #include <KLocalizedString>
 #include <QComboBox>
@@ -74,9 +61,8 @@ Exif::InfoDialog::InfoDialog(const DB::FileName &fileName, QWidget *parent)
     hlay = new QHBoxLayout;
     vlay->addLayout(hlay);
 
-    QLabel *searchLabel = new QLabel(i18n("Exif label search: "), top);
-    hlay->addWidget(searchLabel);
     m_searchBox = new QLineEdit(top);
+    m_searchBox->setPlaceholderText(i18nc("@label:textbox The search box allows the user to filter by exif label names", "Filter labels ..."));
     hlay->addWidget(m_searchBox);
     hlay->addStretch(1);
 
