@@ -1,26 +1,15 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #ifndef EXIFSEARCHDIALOG_H
 #define EXIFSEARCHDIALOG_H
 
 #include "RangeWidget.h"
 #include "SearchDialogSettings.h"
-#include "SearchInfo.h"
+
+#include <kpaexif/SearchInfo.h>
 
 #include <KPageDialog>
 
@@ -35,7 +24,7 @@ class SearchDialog : public KPageDialog
     Q_OBJECT
 
 public:
-    explicit SearchDialog(QWidget *parent);
+    explicit SearchDialog(const Database *exifDB, QWidget *parent);
     Exif::SearchInfo info();
 
 protected:
@@ -56,6 +45,7 @@ protected slots:
     void toFocalLengthChanged(int);
 
 private:
+    const Exif::Database *m_exifDB;
     Exif::RangeWidget *m_iso;
     Exif::RangeWidget *m_exposureTime;
     Exif::RangeWidget *m_fNumber;
