@@ -1,39 +1,24 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ImageLoaderThread.h"
 
 #include "AsyncLoader.h"
 #include "ImageDecoder.h"
-#include "Logging.h"
+#include "ImageEvent.h"
 #include "RawImageDecoder.h"
-#include "ThumbnailCache.h"
 
 #include <Utilities/FastJpeg.h>
 #include <Utilities/ImageUtil.h>
+#include <kpabase/Logging.h>
+#include <kpathumbnails/ThumbnailCache.h>
 
 #include <QApplication>
 #include <QFileInfo>
 #include <QLoggingCategory>
 
-#include "ImageEvent.h"
-
-#include <kcodecs.h>
 #include <qmatrix.h>
 
 namespace ImageManager
