@@ -1,20 +1,8 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2020 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #include "ImageRow.h"
 
 #include "ImportDialog.h"
@@ -55,7 +43,6 @@ void ImageRow::showImage()
                 src = src2;
             src = src.adjusted(QUrl::RemoveFilename);
             src.setPath(src.path() + m_info->fileName().relative());
-            QString tmpFile;
 
             std::unique_ptr<KIO::StoredTransferJob> downloadJob { KIO::storedGet(src) };
             KJobWidgets::setWindow(downloadJob.get(), MainWindow::Window::theMainWindow());
