@@ -1,20 +1,8 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #include "BreadcrumbViewer.h"
 
 #include <QTextDocument>
@@ -42,6 +30,9 @@ MainWindow::BreadcrumbViewer::BreadcrumbViewer()
  */
 void MainWindow::BreadcrumbViewer::updateText()
 {
+    if (m_activeCrumbs.isEmpty())
+        return;
+
     QStringList htmlList;
 
     for (int i = 0; i < m_activeCrumbs.count() - 1; ++i)
