@@ -1,19 +1,6 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "SplashScreen.h"
@@ -56,6 +43,8 @@ void MainWindow::SplashScreen::drawContents(QPainter *painter)
     QFont font = painter->font();
     font.setPointSize(10);
     painter->setFont(font);
+    // Currently background is white, we need a contrast color
+    painter->setPen(Qt::black);
     QRect r = QRect(QPoint(20, 265), QSize(360, 25));
 
     // Version String
