@@ -1,27 +1,17 @@
-/* Copyright (C) 2018-2019 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2018-2019 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef GEOCOORDINATES_H
 #define GEOCOORDINATES_H
 
 #include <QString>
 
+namespace Marble
+{
+class GeoDataLatLonBox;
+}
 namespace Map
 {
 
@@ -40,8 +30,10 @@ public:
     struct LatLonBox {
         LatLonBox() = default;
         LatLonBox(double north, double south, double east, double west);
+        explicit LatLonBox(const Marble::GeoDataLatLonBox &box);
         bool isNull() const;
         operator QString() const;
+        bool contains(const GeoCoordinates &point) const;
         double north = 0;
         double south = 0;
         double east = 0;
