@@ -1,47 +1,37 @@
-/* Copyright (C) 2014 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2014 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "RemoteConnection.h"
+
 #include "RemoteCommand.h"
 
+#include <QApplication>
 #include <QBuffer>
 #include <QTcpSocket>
-#include <QApplication>
 #include <QThread>
 #include <QTime>
 
 #if 0
-#  define protocolDebug qDebug
+#define protocolDebug qDebug
 #else
-#  define protocolDebug if (false) qDebug
+#define protocolDebug \
+    if (false)        \
+    qDebug
 #endif
 
 using namespace RemoteControl;
 
-RemoteConnection::RemoteConnection(QObject *parent) :
-    QObject(parent)
+RemoteConnection::RemoteConnection(QObject *parent)
+    : QObject(parent)
 {
 }
 
-void RemoteConnection::sendCommand(const RemoteCommand& command)
+void RemoteConnection::sendCommand(const RemoteCommand &command)
 {
     protocolDebug() << qPrintable(QTime::currentTime().toString(QString::fromUtf8("hh:mm:ss.zzz")))
-                    << ": Sending " << QString::number((int) command.commandType());
+                    << ": Sending " << QString::number((int)command.commandType());
     Q_ASSERT(QThread::currentThread() == qApp->thread());
 
     if (!isConnected())
@@ -55,15 +45,15 @@ void RemoteConnection::sendCommand(const RemoteCommand& command)
     QDataStream stream(&buffer);
 
     // stream a placeholder for the length
-    stream << (qint32) 0;
+    stream << (qint32)0;
 
     // Steam the id and the data
-    stream << (qint32) command.commandType();
+    stream << (qint32)command.commandType();
     command.encode(stream);
 
     // Wind back and stream the length
     stream.device()->seek(0);
-    stream << (qint32) buffer.size();
+    stream << (qint32)buffer.size();
 
     // Send the data.
     socket()->write(buffer.data());
@@ -72,7 +62,7 @@ void RemoteConnection::sendCommand(const RemoteCommand& command)
 
 void RemoteConnection::dataReceived()
 {
-    QTcpSocket* socket = this->socket();
+    QTcpSocket *socket = this->socket();
     if (!socket)
         return;
 
@@ -80,7 +70,7 @@ void RemoteConnection::dataReceived()
 
     while (socket->bytesAvailable()) {
         if (m_state == WaitingForLength) {
-            if (socket->bytesAvailable() < (qint64) sizeof(qint32))
+            if (socket->bytesAvailable() < (qint64)sizeof(qint32))
                 return;
 
             stream >> m_length;
@@ -105,15 +95,9 @@ void RemoteConnection::dataReceived()
             std::unique_ptr<RemoteCommand> command = RemoteCommand::create(static_cast<CommandType>(id));
             command->decode(stream);
             protocolDebug() << qPrintable(QTime::currentTime().toString(QString::fromUtf8("hh:mm:ss.zzz")))
-                               << ": Received " << id;
+                            << ": Received " << id;
 
             emit gotCommand(*command);
         }
     }
 }
-
-
-
-
-
-
