@@ -1,20 +1,7 @@
-/* Copyright (C) 2014-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2014-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 // Qt includes
 #include <QCalendarWidget>
@@ -65,10 +52,10 @@ Settings::BirthdayPage::BirthdayPage(QWidget *parent)
     connect(m_categoryBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &BirthdayPage::changeCategory);
 
     m_filter = new QLineEdit;
-    m_filter->setPlaceholderText(i18n("Filter (Alt+f)"));
     itemsHeaderLayout->addWidget(m_filter);
     connect(m_filter, &QLineEdit::textChanged, this, &BirthdayPage::resetCategory);
-    new QShortcut(Qt::AltModifier + Qt::Key_F, m_filter, SLOT(setFocus()));
+    const auto filterShortcut = new QShortcut(Qt::AltModifier + Qt::Key_F, m_filter, SLOT(setFocus()));
+    m_filter->setPlaceholderText(i18nc("@label:textedit", "Filter ... (%1)", filterShortcut->key().toString(QKeySequence::NativeText)));
 
     if (QLocale().dateFormat(QLocale::ShortFormat).contains(QString::fromUtf8("yyyy"))) {
         m_dateFormats << QLocale().dateFormat(QLocale::ShortFormat);
