@@ -1,33 +1,17 @@
-/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CATEGORYPAGE_H
 #define CATEGORYPAGE_H
 
-// Qt includes
+#include <kpabase/SettingsData.h>
+
 #include <QAbstractItemDelegate>
 #include <QLabel>
 #include <QWidget>
 
-// Local includes
-#include "SettingsData.h"
-
-// Qt classes
 class QListWidget;
 class QListWidgetItem;
 class QComboBox;
@@ -35,8 +19,6 @@ class QSpinBox;
 class QCheckBox;
 class QPushButton;
 class QGroupBox;
-
-// KDE classes
 class KIconButton;
 
 namespace DB
