@@ -1,24 +1,17 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "TagGroupsPage.h"
+#include "CategoriesGroupsWidget.h"
 
-// Qt includes
+#include <DB/CategoryCollection.h>
+#include <MainWindow/DirtyIndicator.h>
+#include <kpabase/SettingsData.h>
+
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <QAction>
 #include <QFont>
 #include <QGridLayout>
@@ -31,17 +24,6 @@
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 
-// KDE includes
-#include <KLocalizedString>
-#include <KMessageBox>
-
-// Local includes
-#include "CategoriesGroupsWidget.h"
-#include "SettingsData.h"
-
-#include <DB/CategoryCollection.h>
-#include <MainWindow/DirtyIndicator.h>
-
 Settings::TagGroupsPage::TagGroupsPage(QWidget *parent)
     : QWidget(parent)
 {
@@ -517,7 +499,6 @@ void Settings::TagGroupsPage::slotDeleteGroup()
 {
     QTreeWidgetItem *currentItem = m_categoryTreeWidget->currentItem();
     QString message;
-    QString title;
 
     if (currentItem->childCount() > 0) {
         message = xi18nc("@info", "<para>Really delete group \"%1\"?</para>"
