@@ -1,20 +1,8 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #include "KeyboardEventHandler.h"
 
 #include "CellGeometry.h"
@@ -26,7 +14,7 @@
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
 #include <MainWindow/DirtyIndicator.h>
-#include <Settings/SettingsData.h>
+#include <kpabase/SettingsData.h>
 
 ThumbnailView::KeyboardEventHandler::KeyboardEventHandler(ThumbnailFactory *factory)
     : ThumbnailComponent(factory)
@@ -104,6 +92,11 @@ bool ThumbnailView::KeyboardEventHandler::keyPressEvent(QKeyEvent *event)
         return true;
     }
 
+    if (event->key() == Qt::Key_Slash) {
+        emit showSearch();
+        return true;
+    }
+
     return false;
 }
 
