@@ -1,30 +1,22 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #ifndef THUMBNAILFACADE_H
 #define THUMBNAILFACADE_H
 #include "ThumbnailFactory.h"
 #include "ThumbnailWidget.h"
 
-#include <DB/FileNameList.h>
+#include <kpabase/FileNameList.h>
 
 class KActionCollection;
 class QSlider;
 
+namespace DB
+{
+class ImageSearchInfo;
+}
 namespace ImageManager
 {
 class ThumbnailCache;
@@ -79,15 +71,18 @@ public slots:
     void slotRecreateThumbnail();
 
     void clearFilter();
+    void setFreeformFilter(const QString &text);
 
 signals:
     void showImage(const DB::FileName &id);
     void showSelection();
+    void showSearch();
     void fileIdUnderCursorChanged(const DB::FileName &id);
-    void currentDateChanged(const QDateTime &);
+    void currentDateChanged(const Utilities::FastDateTime &);
     void selectionChanged(int numberOfItemsSelected);
     void collapseAllStacksEnabled(bool enabled);
     void expandAllStacksEnabled(bool enabled);
+    void filterChanged(const DB::ImageSearchInfo &);
 
 private:
     ThumbnailModel *model() override;
