@@ -1,20 +1,7 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "ThumbnailWidget.h"
 
@@ -29,7 +16,7 @@
 #include <Browser/BrowserWidget.h>
 #include <DB/ImageDB.h>
 #include <DB/ImageInfoPtr.h>
-#include <Settings/SettingsData.h>
+#include <kpabase/SettingsData.h>
 
 #include <KColorScheme>
 #include <KLocalizedString>
@@ -85,6 +72,7 @@ ThumbnailView::ThumbnailWidget::ThumbnailWidget(ThumbnailFactory *factory)
 
     connect(&m_mouseTrackingHandler, &MouseTrackingInteraction::fileIdUnderCursorChanged, this, &ThumbnailWidget::fileIdUnderCursorChanged);
     connect(m_keyboardHandler, &KeyboardEventHandler::showSelection, this, &ThumbnailWidget::showSelection);
+    connect(m_keyboardHandler, &KeyboardEventHandler::showSearch, this, &ThumbnailWidget::showSearch);
 
     updatePalette();
     connect(Settings::SettingsData::instance(), &Settings::SettingsData::colorSchemeChanged, this, &ThumbnailWidget::updatePalette);
@@ -211,8 +199,13 @@ void ThumbnailView::ThumbnailWidget::wheelEvent(QWheelEvent *event)
         cellGeometryInfo()->calculateCellSize();
         model()->endResetModel();
     } else {
+#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
+        const int delta = event->delta() / 5;
+        QWheelEvent newevent = QWheelEvent(event->pos(), delta, event->buttons(), event->modifiers());
+#else
         const auto angleDelta = event->angleDelta() / 5;
         QWheelEvent newevent = QWheelEvent(event->pos(), event->globalPos(), event->pixelDelta(), angleDelta, event->buttons(), event->modifiers(), event->phase(), event->inverted());
+#endif
 
         QListView::wheelEvent(&newevent);
         event->setAccepted(newevent.isAccepted());
@@ -232,8 +225,8 @@ void ThumbnailView::ThumbnailWidget::emitDateChange()
     if (fileName.isNull())
         return;
 
-    static QDateTime lastDate;
-    const QDateTime date = DB::ImageDB::instance()->info(fileName)->date().start();
+    static Utilities::FastDateTime lastDate;
+    const Utilities::FastDateTime date = DB::ImageDB::instance()->info(fileName)->date().start();
     if (date != lastDate) {
         lastDate = date;
         if (date.date().year() != 1900)
