@@ -1,19 +1,6 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef IMAGEDISPLAY_H
@@ -21,10 +8,10 @@
 
 #include "AbstractDisplay.h"
 
-#include <DB/FileNameList.h>
 #include <DB/ImageInfoPtr.h>
 #include <ImageManager/ImageClientInterface.h>
-#include <Settings/SettingsData.h>
+#include <kpabase/FileNameList.h>
+#include <kpabase/SettingsData.h>
 
 #include <QMouseEvent>
 #include <QPaintEvent>
@@ -44,7 +31,7 @@ class ViewHandler;
 class ViewerWidget;
 
 struct ViewPreloadInfo {
-    ViewPreloadInfo() {}
+    ViewPreloadInfo() { }
     ViewPreloadInfo(const QImage &img, const QSize &size, int angle)
         : img(img)
         , size(size)
