@@ -1,36 +1,10 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "InfoBox.h"
 
-// Qt includes
-#include <QApplication>
-#include <QBitmap>
-#include <QDesktopWidget>
-#include <QMouseEvent>
-#include <QScrollBar>
-#include <QToolButton>
-
-// KDE includes
-#include <KActionCollection>
-#include <KLocalizedString>
-#include <KRatingWidget>
-
 // Local includes
 #include <Browser/BrowserWidget.h>
 #include <DB/ImageDB.h>
@@ -41,6 +15,17 @@
 #endif
 #include "VisibleOptionsMenu.h"
 
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KRatingWidget>
+#include <QApplication>
+#include <QBitmap>
+#include <QDebug>
+#include <QDesktopWidget>
+#include <QMouseEvent>
+#include <QScrollBar>
+#include <QToolButton>
+
 using namespace Settings;
 
 Viewer::InfoBox::InfoBox(Viewer::ViewerWidget *viewer)
