@@ -1,38 +1,20 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef INFOBOX_H
 #define INFOBOX_H
 
-#include "config-kpa-marble.h"
-
-// Qt includes
-#include <QMouseEvent>
-#include <QPointer>
-
-// KDE includes
-#include <QTextBrowser>
-
-// Local includes
 #include "InfoBoxResizer.h"
 #include "ViewerWidget.h"
 
-#include <Settings/SettingsData.h>
+#include <kpabase/SettingsData.h>
+#include <kpabase/config-kpa-marble.h>
+
+#include <QMouseEvent>
+#include <QPointer>
+#include <QTextBrowser>
 
 // Qt classes
 class QMenu;
