@@ -1,20 +1,7 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "ViewerWidget.h"
 
@@ -31,7 +18,6 @@
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
 #include <Exif/InfoDialog.h>
-#include <ImageManager/ThumbnailCache.h>
 #include <MainWindow/CategoryImagePopup.h>
 #include <MainWindow/DeleteDialog.h>
 #include <MainWindow/DirtyIndicator.h>
@@ -39,6 +25,7 @@
 #include <MainWindow/Window.h>
 #include <Utilities/DescriptionUtil.h>
 #include <Utilities/VideoUtil.h>
+#include <kpathumbnails/ThumbnailCache.h>
 
 #include <KActionCollection>
 #include <KColorScheme>
@@ -65,6 +52,8 @@
 #include <QWheelEvent>
 #include <qglobal.h>
 
+#include <functional>
+
 Viewer::ViewerWidget *Viewer::ViewerWidget::s_latest = nullptr;
 
 Viewer::ViewerWidget *Viewer::ViewerWidget::latest()
@@ -92,9 +81,6 @@ Viewer::ViewerWidget::ViewerWidget(UsageType type, QMap<Qt::Key, QPair<QString,
         s_latest = this;
     }
 
-    updatePalette();
-    connect(Settings::SettingsData::instance(), &Settings::SettingsData::colorSchemeChanged, this, &ViewerWidget::updatePalette);
-
     if (!m_inputMacros) {
         m_myInputMacros = m_inputMacros = new QMap<Qt::Key, QPair<QString, QString>>;
     }
@@ -134,6 +120,9 @@ Viewer::ViewerWidget::ViewerWidget(UsageType type, QMap<Qt::Key, QPair<QString,
     QTimer::singleShot(2000, this, &ViewerWidget::test);
 
     connect(DB::ImageDB::instance(), &DB::ImageDB::imagesDeleted, this, &ViewerWidget::slotRemoveDeletedImages);
+
+    updatePalette();
+    connect(Settings::SettingsData::instance(), &Settings::SettingsData::colorSchemeChanged, this, &ViewerWidget::updatePalette);
 }
 
 void Viewer::ViewerWidget::setupContextMenu()
@@ -165,10 +154,19 @@ void Viewer::ViewerWidget::setupContextMenu()
     m_showExifViewer->setText(i18nc("@action:inmenu", "Show Exif Viewer"));
     m_popup->addAction(m_showExifViewer);
 
-    m_copyTo = m_actions->addAction(QString::fromLatin1("viewer-copy-to"), this, &ViewerWidget::copyTo);
-    m_copyTo->setText(i18nc("@action:inmenu", "Copy Image to..."));
-    m_actions->setDefaultShortcut(m_copyTo, Qt::Key_F7);
-    m_popup->addAction(m_copyTo);
+    m_popup->addSeparator();
+
+    m_copyToAction = m_actions->addAction(QStringLiteral("viewer-copy-to"), this, std::bind(&ViewerWidget::triggerCopyLinkAction, this, MainWindow::CopyLinkEngine::Copy));
+    m_copyToAction->setText(i18nc("@action:inmenu", "Copy image to ..."));
+    m_actions->setDefaultShortcut(m_copyToAction, Qt::Key_F7);
+    m_popup->addAction(m_copyToAction);
+
+    m_linkToAction = m_actions->addAction(QStringLiteral("viewer-link-to"), this, std::bind(&ViewerWidget::triggerCopyLinkAction, this, MainWindow::CopyLinkEngine::Link));
+    m_linkToAction->setText(i18nc("@action:inmenu", "Link image to ..."));
+    m_actions->setDefaultShortcut(m_linkToAction, Qt::SHIFT + Qt::Key_F7);
+    m_popup->addAction(m_linkToAction);
+
+    m_popup->addSeparator();
 
     if (m_type == ViewerWindow) {
         action = m_actions->addAction(QString::fromLatin1("viewer-close"), this, &ViewerWidget::close);
@@ -190,6 +188,7 @@ void Viewer::ViewerWidget::setupContextMenu()
 void Viewer::ViewerWidget::createShowContextMenu()
 {
     VisibleOptionsMenu *menu = new VisibleOptionsMenu(this, m_actions);
+    menu->setDisabled(m_type == InlineViewer);
     connect(menu, &VisibleOptionsMenu::visibleOptionsChanged, this, &ViewerWidget::updateInfoBox);
     m_popup->addMenu(menu);
 }
@@ -1441,29 +1440,15 @@ void Viewer::ViewerWidget::remapAreas(QSize viewSize, QRect zoomWindow, double s
     }
 }
 
-void Viewer::ViewerWidget::copyTo()
+void Viewer::ViewerWidget::setCopyLinkEngine(MainWindow::CopyLinkEngine *copyLinkEngine)
 {
-    QUrl src = QUrl::fromLocalFile(m_list[m_current].absolute());
-    if (m_lastCopyToTarget.isNull()) {
-        // get directory of src file
-        m_lastCopyToTarget = QFileInfo(src.path()).path();
-    }
+    m_copyLinkEngine = copyLinkEngine;
+}
 
-    QFileDialog dialog(this);
-    dialog.setWindowTitle(i18nc("@title:window", "Copy Image to..."));
-    // use directory of src as start-location:
-    dialog.setDirectory(m_lastCopyToTarget);
-    dialog.selectFile(src.fileName());
-    dialog.setAcceptMode(QFileDialog::AcceptSave);
-    dialog.setLabelText(QFileDialog::Accept, i18nc("@action:button", "Copy"));
-
-    if (dialog.exec()) {
-        QUrl dst = dialog.selectedUrls().first();
-        KIO::CopyJob *job = KIO::copy(src, dst);
-        connect(job, &KIO::CopyJob::finished, job, &QObject::deleteLater);
-        // get directory of dst file
-        m_lastCopyToTarget = QFileInfo(dst.path()).path();
-    }
+void Viewer::ViewerWidget::triggerCopyLinkAction(MainWindow::CopyLinkEngine::Action action)
+{
+    auto selectedFiles = QList<QUrl> { QUrl::fromLocalFile(m_list.value(m_current).absolute()) };
+    m_copyLinkEngine->selectTarget(this, selectedFiles, action);
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
