@@ -1,27 +1,15 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2021 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef VIEWER_H
 #define VIEWER_H
 
-#include <DB/FileNameList.h>
 #include <DB/ImageInfo.h>
 #include <DB/ImageInfoPtr.h>
+#include <kpabase/FileNameList.h>
+#include <MainWindow/CopyLinkEngine.h>
 
 #include <QImage>
 #include <QMap>
@@ -79,6 +67,7 @@ public:
     void setShowFullScreen(bool on);
     void show(bool slideShow);
     KActionCollection *actions();
+    void setCopyLinkEngine(MainWindow::CopyLinkEngine *copyLinkEngine);
 
     /**
      * @brief setTaggedAreasFromImage
@@ -97,7 +86,6 @@ public slots:
     void moveInfoBox(int);
     void stopPlayback();
     void remapAreas(QSize viewSize, QRect zoomWindow, double sizeRatio);
-    void copyTo();
 
 signals:
     void soughtTo(const DB::FileName &id);
@@ -198,6 +186,8 @@ protected slots:
      */
     void slotRemoveDeletedImages(const DB::FileNameList &imageList);
 
+    void triggerCopyLinkAction(MainWindow::CopyLinkEngine::Action action);
+
 private:
     static ViewerWidget *s_latest;
     friend class VideoShooter;
@@ -239,7 +229,8 @@ private:
     QAction *m_showExifViewer;
     QPointer<Exif::InfoDialog> m_exifViewer;
 
-    QAction *m_copyTo;
+    QAction *m_copyToAction;
+    QAction *m_linkToAction;
 
     InfoBox *m_infoBox;
     QImage m_currentImage;
@@ -273,7 +264,7 @@ private:
     QMap<Qt::Key, QPair<QString, QString>> *m_inputMacros;
     QMap<Qt::Key, QPair<QString, QString>> *m_myInputMacros;
 
-    QString m_lastCopyToTarget;
+    MainWindow::CopyLinkEngine *m_copyLinkEngine;
 };
 
 }
