@@ -1,31 +1,20 @@
-/* Copyright (C) 2003-2020 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2020 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #include "VisibleOptionsMenu.h"
 
 #include <DB/Category.h>
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
-#include <Settings/SettingsData.h>
+#include <kpabase/SettingsData.h>
 
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KToggleAction>
 #include <QCheckBox>
+#include <QDebug>
 #include <QList>
 
 Viewer::VisibleOptionsMenu::VisibleOptionsMenu(QWidget *parent, KActionCollection *actions)
@@ -83,12 +72,12 @@ Viewer::VisibleOptionsMenu::VisibleOptionsMenu(QWidget *parent, KActionCollectio
     connect(m_showRating, &KToggleAction::toggled, this, &VisibleOptionsMenu::toggleShowRating);
     addAction(m_showRating);
 
-    QList<DB::CategoryPtr> categories = DB::ImageDB::instance()->categoryCollection()->categories();
-    for (QList<DB::CategoryPtr>::Iterator it = categories.begin(); it != categories.end(); ++it) {
-        KToggleAction *taction = actions->add<KToggleAction>((*it)->name());
+    const QList<DB::CategoryPtr> categories = DB::ImageDB::instance()->categoryCollection()->categories();
+    for (const auto &category : categories) {
+        KToggleAction *taction = actions->add<KToggleAction>(category->name());
         m_actionList.append(taction);
-        taction->setText((*it)->name());
-        taction->setData((*it)->name());
+        taction->setText(category->name());
+        taction->setData(category->name());
         addAction(taction);
         connect(taction, &KToggleAction::toggled, this, &VisibleOptionsMenu::toggleShowCategory);
     }
@@ -168,8 +157,10 @@ void Viewer::VisibleOptionsMenu::updateState()
     m_showImageSize->setChecked(Settings::SettingsData::instance()->showImageSize());
     m_showRating->setChecked(Settings::SettingsData::instance()->showRating());
 
+    const auto categoryCollection = DB::ImageDB::instance()->categoryCollection();
     for (KToggleAction *action : qAsConst(m_actionList)) {
-        action->setChecked(DB::ImageDB::instance()->categoryCollection()->categoryForName(action->data().value<QString>())->doShow());
+        const auto category = categoryCollection->categoryForName(action->data().value<QString>());
+        action->setChecked(category->doShow());
     }
 }
 
