@@ -1,19 +1,6 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef XMLIMAGEDATECOLLECTION_H
 #define XMLIMAGEDATECOLLECTION_H
@@ -36,12 +23,12 @@ public:
 
 public:
     DB::ImageCount count(const DB::ImageDate &range) override;
-    QDateTime lowerLimit() const override;
-    QDateTime upperLimit() const override;
+    Utilities::FastDateTime lowerLimit() const override;
+    Utilities::FastDateTime upperLimit() const override;
 
 private:
-    typedef QMap<QDateTime, DB::ImageDate> StartIndexMap;
-    typedef QMap<QDateTime, StartIndexMap::ConstIterator> EndIndexMap;
+    typedef QMap<Utilities::FastDateTime, DB::ImageDate> StartIndexMap;
+    typedef QMap<Utilities::FastDateTime, StartIndexMap::ConstIterator> EndIndexMap;
 
     void add(const DB::ImageDate &);
 
